@@ -22,18 +22,25 @@ public:
     static ControllerManager &instance();
     
     void newDevice(Device *device);
+    void deviceRemoved(Device *device);
     bool isConnected(QString uniqueIdentifier);
     QVector<Device*> getDevicesByType(DeviceType deviceType);
 
+    /** Have input not forward events to the OS */
+    void noopInput();
+
 public slots:
-    void emitKey(int key, bool pressed);
+    void emitKey(int key, bool pressed) const;
     void removeDevice(int deviceIndex);
+    QVector<Device*> connectedDevices();
 
 Q_SIGNALS:
     void deviceConnected(Device*);
     void deviceDisconnected(Device*);
 
 private:
+    QStringList m_applicationInhibit;
+    bool m_enabled = true;
     QVector<Device*> m_connectedDevices;
     QScopedPointer<AbstractSystem> m_inputSystem;
 };
